Index: TXM/trunk/org.txm.internalview.rcp/src/org/txm/internalview/rcp/handlers/SendInternalViewTo.java
===================================================================
--- TXM/trunk/org.txm.internalview.rcp/src/org/txm/internalview/rcp/handlers/SendInternalViewTo.java	(revision 3562)
+++ TXM/trunk/org.txm.internalview.rcp/src/org/txm/internalview/rcp/handlers/SendInternalViewTo.java	(revision 3563)
@@ -29,7 +29,6 @@
 
 import org.eclipse.core.commands.ExecutionEvent;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.ui.handlers.HandlerUtil;
 import org.txm.internalview.rcp.editors.InternalViewEditor;
@@ -48,6 +47,7 @@
 	public String createQuery(ExecutionEvent event, ISelection selection) {
 		if (selection instanceof StructuredSelection) {
 			StructuredSelection sselection = (StructuredSelection) selection;
+			//FIXME: SJ: the selection is not used
 			return ((InternalViewEditor) HandlerUtil.getActiveWorkbenchWindow(event).getActivePage().getActivePart()).createQuery();
 		}
 		return null;
Index: TXM/trunk/org.txm.progression.rcp/src/org/txm/progression/rcp/handlers/ComputeProgression.java
===================================================================
--- TXM/trunk/org.txm.progression.rcp/src/org/txm/progression/rcp/handlers/ComputeProgression.java	(revision 3562)
+++ TXM/trunk/org.txm.progression.rcp/src/org/txm/progression/rcp/handlers/ComputeProgression.java	(revision 3563)
@@ -58,6 +58,7 @@
 		Progression progression = null;
 		
 		// From link: creating from parameter node
+		//FIXME: SJ: all "Send to" commands have a different node path schema since we do not know the target class in the source handler (the class string is replaced with "_link")  
 		String parametersNodePath = event.getParameter(TXMPreferences.RESULT_PARAMETERS_NODE_PATH);
 		if (parametersNodePath != null && !parametersNodePath.isEmpty()) {
 			progression = new Progression(parametersNodePath);
Index: TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditor.java
===================================================================
--- TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditor.java	(revision 3562)
+++ TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditor.java	(revision 3563)
@@ -994,10 +994,34 @@
 					
 					notifyExtensions("notifyStartOfCompute"); //$NON-NLS-1$
 					
+					
+					// FIXME: SJ: tests for using the delay managed ComputeProgressMonitorDialog.
+					// Purpose is to display a Modal Dialog only after an amount of time
+					// At this time the monitor is only used in OpenEditor, need to see if we need it for all computing process
+					// Actually the system may be robust enough now to not use a modal dialog event in OpenEditor?
+//					this.syncExec(new Runnable() {
+//						
+//						@Override
+//						public void run() {
+//							
+//							try {
+//								ComputeProgressMonitorDialog dialog = new ComputeProgressMonitorDialog(getShell(), TXMEditor.this.getResult());
+//								dialog.runComputingProcess(true);
+//							}
+//							catch (Exception e) {
+//								Log.printStackTrace(e);
+//							}
+//						}
+//					});
+
 					if (!TXMEditor.this.getResult().compute(subMonitor.split(50))) {
 						Log.fine("TXMEditor.compute(): " + TXMEditor.this.getClass().getSimpleName() + ": computing failed."); //$NON-NLS-1$ //$NON-NLS-2$
 					}
 					
+					
+					
+					
+					
 					notifyExtensions("notifyEndOfCompute"); //$NON-NLS-1$
 					
 					// monitor.worked(50);
Index: TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/handlers/results/ComputeTXMResult.java
===================================================================
--- TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/handlers/results/ComputeTXMResult.java	(revision 3562)
+++ TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/handlers/results/ComputeTXMResult.java	(revision 3563)
@@ -13,7 +13,7 @@
 import org.txm.rcp.editors.TXMEditorToolBar;
 
 /**
- * Calls TXMEditor.ompute() on the current active editor.
+ * Calls TXMEditor.compute() on the current active editor.
  * 
  * @author mdecorde
  * @author sjacquot
Index: TXM/trunk/org.txm.core/src/java/org/txm/core/preferences/TXMPreferences.java
===================================================================
--- TXM/trunk/org.txm.core/src/java/org/txm/core/preferences/TXMPreferences.java	(revision 3562)
+++ TXM/trunk/org.txm.core/src/java/org/txm/core/preferences/TXMPreferences.java	(revision 3563)
@@ -38,36 +38,29 @@
 
 /**
  * Base preferences initializer and manager.
- * Getters return either a value looking in this order:
- * - local node linked to a TXM result if exists
- * - command global value (InstanceScope)
- * - command default value (DefaultScope)
- * - alternative specified global value
- * - alternative specified default value
- * TODO: methods that puts a value in the local node does not check if the value is the default value of the parent, it should be removed from the local node if it's the default value
- * of command scope or alternative scope so the preference will not be saved in the local scope .prefs file if its a default value.
- * TODO: when we'll use IProject for managing Corporas, the local node should be stored in the ProjectScope instead of in the InstanceScope.
- * TODO: need to determine if we'll use this class to persistence of TXM results. At this moment, we persist result by calling flush() that creates a file named by the result node qualifier,
- * eg. org.txm.partition.core.functions.PartitionDimensions@732982cb.prefs
- * (We can also define a custom Scope to do that, for example to change the saved object location or the filename)
+ * 
+ * Getters return a value of preference looking in this order:
+ * 1) local node linked to a TXM result if exists									(ProjectScope - /project/<project_name>/<UUID of TXMResult>/<preference key>)
+ * 2) command global value															(InstanceScope - /instance/<bundle_id>/<preference key>)
+ * 3) alternative specified global value,
+ * 	 	eg. engine preference added to TXMPreference.alternativeNodesQualifiers		(InstanceScope - /instance/<bundle_id>/<preference key>)
+ * 4) alternative specified default value,
+ *  	eg. engine preference added to TXMPreference.alternativeNodesQualifiers		(DefaultScope - /bundle_defaults/<bundle_id>/<preference key>)
+ * 5) command default value 														(DefaultScope - /bundle_defaults/<bundle_id>/<preference key>)
+ * 6) hard coded in getters
+ * 
+ * Persistence of TXM results is done by calling flush() that creates a file named by the result node qualifier,
  *
  *
  * @author mdecorde
  * @author sjacquot
  *
  */
-// FIXME: AFTER some tests, the local nodes are flushed when editing a Charts engine preference from the UI, actually the prefs are flushed if we change a charts engine preference and then it becomes
-// different from the local result, eg. "Show Legend" or "Rendering colors mode". See if it's what we want.
-// Otherwise, to avoid that we need to define our own Scope, but the problem will disappear when
-// we'll use the ProjectScope.
 public abstract class TXMPreferences extends AbstractPreferenceInitializer {
 	
 	/**
-	 * Scope used for storing the command preferences.
+	 * Root node of the Eclipse preference hierarchy. 
 	 */
-	// public static IScopeContext scope = InstanceScope.INSTANCE;
-	
-	
 	public static IEclipsePreferences preferencesRootNode = Platform.getPreferencesService().getRootNode();
 	
 	/**
@@ -77,18 +70,29 @@
 	
 	
 	// TXMResult internal parameters, essentially for Links and Persistence
+	/**
+	 * Result parameters node path in preferences.
+	 */
 	public final static String RESULT_PARAMETERS_NODE_PATH = "result_parameters_node_path"; //$NON-NLS-1$
 	
+	/**
+	 * Parent parameters node path in preferences.
+	 */
 	public final static String PARENT_PARAMETERS_NODE_PATH = "parent_parameters_node_path"; //$NON-NLS-1$
 	
+	/**
+	 * The class of the TXMResult.
+	 */
 	public final static String CLASS = "class"; //$NON-NLS-1$
 	
+	/**
+	 * The bundle id of the result.
+	 */
 	public final static String BUNDLE_ID = "bundle_id"; //$NON-NLS-1$
 	
 	public final static String USER_NAME = "user_name"; //$NON-NLS-1$
 	
 	public final static String LAZY_NAME = "lazy_name"; //$NON-NLS-1$
-	
 	public final static String VISIBLE = "visible"; //$NON-NLS-1$
 	
 	public static final String LOCK = "locked_result"; //$NON-NLS-1$
@@ -102,12 +106,20 @@
 	 * Last computing date of a result.
 	 */
 	public static final String LAST_COMPUTING_DATE = "last_computing_date";
-	// end of TXMResult internal parameters
+	// End of TXMResult internal parameters	
+
 	
+	// FIXME: SJ: do not store the "persistable" state in the preferences and file 
+	public static final String PERSITABLE = "persistable";
+
+	// FIXME: SJ: became useless?
+	public static final String INTERNAL_PERSITABLE = "internal_persistable";
+
 	
 	
 	
-	// Command preferences shared strings
+	
+	// Command preferences shared keys strings
 	/**
 	 * Queries.
 	 */
@@ -184,17 +196,15 @@
 	public static final String V_MAX = "v_max"; //$NON-NLS-1$
 	
 	/**
-	 * Separator used when converting list from and to string.
+	 * Separator used when converting a list from and to a string.
 	 */
 	public static final String LIST_SEPARATOR = "\t"; //$NON-NLS-1$
 	
-	
 	/**
 	 * Separator used when building some name based on a parent name and the result name (e.g. VOEUX/text@loc).
 	 */
 	public static final String PARENT_NAME_SEPARATOR = "/"; //$NON-NLS-1$
 	
-	
 	/**
 	 * Number of lines to display per result page.
 	 */
@@ -226,12 +236,11 @@
 	public final static String DEFAULT_STRUCTURAL_UNIT_PROPERTY = "text_id"; //$NON-NLS-1$
 	// End of command preferences shared strings
 	
-	public static final String PERSITABLE = "persistable";
-
-	public static final String INTERNAL_PERSITABLE = "internal_persistable";
 	
+	
+	
 	/**
-	 * Preferences node qualifier of the instance.
+	 * Preferences node qualifier of the instance of the preferences initializer and manager.
 	 */
 	protected String commandPreferencesNodeQualifier;
 	
@@ -245,9 +254,8 @@
 	 * Sub classes should not forget to call this to set TXMResults main behavior (visible, etc...)
 	 */
 	@Override
-	// FIXME: SJ: defines an abstract method as _initializeDefaultPreferences() called here and that must be implemented by subclasses
+	// FIXME: SJ: define an abstract method as _initializeDefaultPreferences() called here and that must be implemented by subclasses
 	public void initializeDefaultPreferences() {
-		
 		Preferences preferences = this.getDefaultPreferencesNode();
 		preferences.putBoolean(TBXPreferences.VISIBLE, true);
 		preferences.putBoolean(TBXPreferences.LOCK, false);
@@ -332,7 +340,7 @@
 	
 	
 	
-	
+	//FIXME
 	// /**
 	// * Stores a pairs of key / value in a local node dedicated to the specified result. The node qualifier is generated by the <code>Object.toString()</code> method.
 	// *
@@ -484,7 +492,13 @@
 		return getBoolean(key, result, nodePath);
 	}
 	
-	
+	/**
+	 * 
+	 * @param key
+	 * @param commandParameters
+	 * @param result
+	 * @return
+	 */
 	public static boolean getBoolean(String key, TXMParameters commandParameters, TXMResult result) {
 		return getBoolean(key, commandParameters, result, result.getCommandPreferencesNodePath());
 	}
@@ -1040,11 +1054,50 @@
 		return getFloat(key, commandParameters, result, result.getCommandPreferencesNodePath());
 	}
 	
+	
+	
 	/**
 	 * Looks for the value of the specified <code>key</code> in preference nodes.
 	 * Returns the value of the local result node if exists.
 	 * Otherwise try to get it from the specified node qualifier if exists.
 	 * Otherwise try to get it from the specified alternative node qualifiers defined in the list <code>TXMPreferences.alternativeNodesQualifiers</code>.
+	 * Returns 0f if no value has been found for the specified key.
+	 * 
+	 * @param nodePath
+	 * @param result
+	 * @param key
+	 * @return
+	 */
+	public static float getFloat(String key, TXMResult result, String nodePath) {
+		return getFloat(key, nodePath, result, 0f);
+	}
+	
+	
+	/**
+	 *
+	 * @param nodePath
+	 * @param key
+	 * @return
+	 */
+	public static float getFloat(String key, String nodePath) {
+		return getFloat(key, null, nodePath);
+	}
+	
+	/**
+	 *
+	 * @param result
+	 * @param key
+	 * @return
+	 */
+	public static float getFloat(String key, TXMResult result) {
+		return getFloat(key, result, null);
+	}
+	
+	/**
+	 * Looks for the value of the specified <code>key</code> in preference nodes.
+	 * Returns the value of the local result node if exists.
+	 * Otherwise try to get it from the specified node qualifier if exists.
+	 * Otherwise try to get it from the specified alternative node qualifiers defined in the list <code>TXMPreferences.alternativeNodesQualifiers</code>.
 	 * Returns defaultValue if no value has been found for the specified key.
 	 * 
 	 * @param nodePath
@@ -1097,46 +1150,8 @@
 		return null;
 	}
 	
-	
+
 	/**
-	 * Looks for the value of the specified <code>key</code> in preference nodes.
-	 * Returns the value of the local result node if exists.
-	 * Otherwise try to get it from the specified node qualifier if exists.
-	 * Otherwise try to get it from the specified alternative node qualifiers defined in the list <code>TXMPreferences.alternativeNodesQualifiers</code>.
-	 * Returns 0f if no value has been found for the specified key.
-	 * 
-	 * @param nodePath
-	 * @param result
-	 * @param key
-	 * @return
-	 */
-	public static float getFloat(String key, TXMResult result, String nodePath) {
-		return getFloat(key, nodePath, result, 0f);
-	}
-	
-	
-	/**
-	 *
-	 * @param nodePath
-	 * @param key
-	 * @return
-	 */
-	public static float getFloat(String key, String nodePath) {
-		return getFloat(key, null, nodePath);
-	}
-	
-	/**
-	 *
-	 * @param result
-	 * @param key
-	 * @return
-	 */
-	public static float getFloat(String key, TXMResult result) {
-		return getFloat(key, result, null);
-	}
-	
-	
-	/**
 	 * Checks if a local node exists for the specified TXM result.
 	 * 
 	 * @param result
@@ -1559,21 +1574,23 @@
 		if (keyExists) {
 			return result.getParametersNodePath();
 		}
-		// look in the instance scope
+		// look in the instance scope (user command preference)
 		else if (keyExists("instance/" + nodePath, key)) {
 			return "instance/" + nodePath;
 		}
 		// look in the global alternative preferences nodes
 		else {
 			for (int i = 0; i < alternativeNodesQualifiers.size(); i++) {
+				// user preference
 				if (keyExists("instance/" + alternativeNodesQualifiers.get(i), key)) {
 					return "instance/" + alternativeNodesQualifiers.get(i);
 				}
+				// default preference
 				else if (keyExists("default/" + alternativeNodesQualifiers.get(i), key)) {
 					return "default/" + alternativeNodesQualifiers.get(i);
 				}
 			}
-			
+			// default command preference
 			return "default/" + nodePath;
 		}
 		
Index: TXM/trunk/org.txm.core/src/java/org/txm/objects/Project.java
===================================================================
--- TXM/trunk/org.txm.core/src/java/org/txm/objects/Project.java	(revision 3562)
+++ TXM/trunk/org.txm.core/src/java/org/txm/objects/Project.java	(revision 3563)
@@ -1454,7 +1454,7 @@
 	 * @return the project parameters root node path
 	 */
 	public String getParametersNodeRootPath() {
-		return "/project/" + this.rcpProject.getName() + "/";
+		return "/project/" + this.rcpProject.getName() + "/"; //$NON-NLS-1$ //$NON-NLS-2$
 	}
 	
 	/**
Index: TXM/trunk/org.txm.partition.core/src/org/txm/partition/core/preferences/PartitionDimensionsPreferences.java
===================================================================
--- TXM/trunk/org.txm.partition.core/src/org/txm/partition/core/preferences/PartitionDimensionsPreferences.java	(revision 3562)
+++ TXM/trunk/org.txm.partition.core/src/org/txm/partition/core/preferences/PartitionDimensionsPreferences.java	(revision 3563)
@@ -7,6 +7,7 @@
 
 /**
  * Default preferences initializer.
+ * 
  * @author sjacquot
  *
  */
@@ -26,6 +27,7 @@
 		return TXMPreferences.instances.get(PartitionDimensionsPreferences.class);
 	}
 	
+	
 	@Override
 	public void initializeDefaultPreferences() {
 		super.initializeDefaultPreferences();
Index: TXM/trunk/org.txm.progression.core/src/org/txm/progression/core/functions/Progression.java
===================================================================
--- TXM/trunk/org.txm.progression.core/src/org/txm/progression/core/functions/Progression.java	(revision 3562)
+++ TXM/trunk/org.txm.progression.core/src/org/txm/progression/core/functions/Progression.java	(revision 3563)
@@ -145,7 +145,6 @@
 	@Parameter(key = ProgressionPreferences.PROPERTY_REGEX)
 	protected String propertyRegex;
 	
-	
 	/**
 	 * Repeats or not the same value when displaying the section markers.
 	 */
Index: TXM/trunk/org.txm.chartsengine.jfreechart.core/src/org/txm/chartsengine/jfreechart/core/themes/base/JFCTheme.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.jfreechart.core/src/org/txm/chartsengine/jfreechart/core/themes/base/JFCTheme.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.jfreechart.core/src/org/txm/chartsengine/jfreechart/core/themes/base/JFCTheme.java	(revision 3563)
@@ -144,16 +144,16 @@
 		Font baseFont = ChartsEngine.createFont(result.getFont());
 		
 		// Titles
-		this.setExtraLargeFont(baseFont.deriveFont(Font.BOLD, baseFont.getSize() + 5));
+		this.setExtraLargeFont(baseFont.deriveFont(baseFont.getStyle(), baseFont.getSize() + 5));
 		
 		// Axis
-		this.setLargeFont(baseFont.deriveFont(Font.BOLD, baseFont.getSize() + 4)); // axis labels
+		this.setLargeFont(baseFont.deriveFont(baseFont.getStyle(), baseFont.getSize() + 4)); // axis labels
 		
-		// FIXME: use for what chart items? maybe annotations?
-		this.setSmallFont(baseFont.deriveFont(Font.BOLD, this.getExtraLargeFont().getSize() - 1));
+		// FIXME: SJ: used for what chart items? maybe annotations?
+		this.setSmallFont(baseFont.deriveFont(baseFont.getStyle(), this.getExtraLargeFont().getSize() - 1));
 		
 		// Item labels, legend labels, axis ticks labels
-		this.regularFont = baseFont.deriveFont(Font.BOLD, baseFont.getSize());
+		this.regularFont = baseFont.deriveFont(baseFont.getStyle(), baseFont.getSize());
 		this.setRegularFont(this.regularFont);
 		
 	}
@@ -240,7 +240,7 @@
 	
 	/**
 	 * Creates a chart panel with theme settings.
-	 * The overriding methods of subclass should manually call :
+	 * The overriding methods of subclass should manually calls:
 	 * <code>
 	 * // Apply theme to the chart
 	 * 	if(chartPanel.getChart() != null)	{
Index: TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/swt/AdvancedChartEditorToolBar.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/swt/AdvancedChartEditorToolBar.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/swt/AdvancedChartEditorToolBar.java	(revision 3563)
@@ -5,9 +5,11 @@
 import java.util.ArrayList;
 
 import org.apache.commons.lang.StringUtils;
+import org.eclipse.jface.resource.StringConverter;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
+import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.ToolItem;
@@ -21,7 +23,6 @@
 import org.txm.chartsengine.rcp.messages.ChartsUIMessages;
 import org.txm.core.engines.EngineType;
 import org.txm.core.preferences.TBXPreferences;
-import org.txm.core.preferences.TXMPreferences;
 import org.txm.rcp.IImageKeys;
 import org.txm.rcp.preferences.RCPPreferences;
 import org.txm.rcp.swt.GLComposite;
@@ -30,6 +31,7 @@
  * The default advanced chart editor tool bar shared by every <code>ChartEditor</code>.
  * The tool bar is accessible and usable in plugin.xml with the URI toolbar:AdvancedChartEditorToolBar.
  * 
+ * @author mdecorde
  * @author sjacquot
  *
  */
@@ -44,10 +46,10 @@
 	private Combo fontSizeCombo;
 	private Combo chartTypeCombo;
 	private Font currentFont;
-	//private Combo fontStyleCombo;
+	private Combo fontStyleCombo;
 	
 	/**
-	 *
+	 * Creates a new chart editor tool bar dedicated to advanced parameters.
 	 * @param parent
 	 * @param style
 	 */
@@ -56,9 +58,9 @@
 		
 		if (!chartEditor.getResult().isEmptyPreference(ChartsEnginePreferences.SHOW_TITLE)) {
 			showTitleButton = new ToolItem(this, SWT.CHECK);
-			// showTitle.setText(SWTComponentsProviderMessages.showhideTitle);
-			showTitleButton.setImage(IImageKeys.getImage(getClass(), "icons/show_title.png"));
-			showTitleButton.setDisabledImage(IImageKeys.getImage(getClass(), "icons/show_title_disabled.png"));
+			// showTitleButton.setText(SWTComponentsProviderMessages.showhideTitle);
+			showTitleButton.setImage(IImageKeys.getImage(getClass(), "icons/show_title.png")); //$NON-NLS-1$
+			showTitleButton.setDisabledImage(IImageKeys.getImage(getClass(), "icons/show_title_disabled.png")); //$NON-NLS-1$
 			showTitleButton.setToolTipText(ChartsUIMessages.showhideTitle);
 			
 			showTitleButton.setSelection(chartEditor.getResult().isTitleVisible());
@@ -70,9 +72,9 @@
 		
 		if (!chartEditor.getResult().isEmptyPreference(ChartsEnginePreferences.SHOW_LEGEND)) {
 			showLegendButton = new ToolItem(this, SWT.CHECK);
-			// showLegend.setText(SWTComponentsProviderMessages.showhideLegend);
-			showLegendButton.setImage(IImageKeys.getImage(getClass(), "icons/show_legend.png"));
-			showLegendButton.setDisabledImage(IImageKeys.getImage(getClass(), "icons/show_legend_disabled.png"));
+			// showLegendButton.setText(SWTComponentsProviderMessages.showhideLegend);
+			showLegendButton.setImage(IImageKeys.getImage(getClass(), "icons/show_legend.png")); //$NON-NLS-1$
+			showLegendButton.setDisabledImage(IImageKeys.getImage(getClass(), "icons/show_legend_disabled.png")); //$NON-NLS-1$
 			showLegendButton.setToolTipText(ChartsUIMessages.showhideLegend);
 			
 			showLegendButton.setSelection(chartEditor.getResult().isLegendVisible());
@@ -84,12 +86,11 @@
 		
 		if (!chartEditor.getResult().isEmptyPreference(ChartsEnginePreferences.SHOW_GRID)) {
 			showGridButton = new ToolItem(this, SWT.CHECK);
-			// showGrid.setText(SWTComponentsProviderMessages.showhideGrid);
-			showGridButton.setImage(IImageKeys.getImage(getClass(), "icons/show_grid.png"));
-			showGridButton.setDisabledImage(IImageKeys.getImage(getClass(), "icons/show_grid_disabled.png"));
+			// showGridButton.setText(SWTComponentsProviderMessages.showhideGrid);
+			showGridButton.setImage(IImageKeys.getImage(getClass(), "icons/show_grid.png")); //$NON-NLS-1$
+			showGridButton.setDisabledImage(IImageKeys.getImage(getClass(), "icons/show_grid_disabled.png")); //$NON-NLS-1$
 			showGridButton.setToolTipText(ChartsUIMessages.showhideGrid);
 			
-			
 			showGridButton.setSelection(chartEditor.getResult().isGridVisible());
 		}
 		//		// disable if not managed by the command
@@ -109,11 +110,12 @@
 			};
 			renderingModeCombo.setItems(colorsModes);
 			
-			ToolItem renderingComboItem = new ToolItem(this, SWT.SEPARATOR);
-			renderingComboItem.setControl(renderingModeCombo);
-			renderingModeCombo.pack();
-			renderingComboItem.setWidth(renderingModeCombo.getBounds().width);
+//			ToolItem renderingComboItem = new ToolItem(this, SWT.SEPARATOR);
+//			renderingComboItem.setControl(renderingModeCombo);
+//			renderingModeCombo.pack();
+//			renderingComboItem.setWidth(renderingModeCombo.getBounds().width);
 			
+			this.addControl(renderingModeCombo);
 			
 			renderingModeCombo.select(chartEditor.getResult().getRenderingColorsMode());
 		}
@@ -125,16 +127,19 @@
 		
 		// Font selection
 		currentFont = ChartsEngine.createFont(chartEditor.getResult().getFont());
-		
+
+		 // FIXME: SJ: may be better here to get the fonts from SWT rather than from Java, see  java.awt.GraphicsEnvironment.getLocalGraphicsEnvironment().getAllFonts();
 		fontCombo = new Combo(this, SWT.READ_ONLY);
-		String fonts[] = GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames(); // FIXME: SJ: may be better here to get the fonts from SWT rather than from Java, see  java.awt.GraphicsEnvironment.getLocalGraphicsEnvironment().getAllFonts();
+		String fonts[] = GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
 		fontCombo.setItems(fonts);
 		
-		ToolItem fontsComboItem = new ToolItem(this, SWT.SEPARATOR);
-		fontsComboItem.setControl(fontCombo);
-		fontCombo.pack();
-		fontsComboItem.setWidth(fontCombo.getBounds().width);
+//		ToolItem fontsComboItem = new ToolItem(this, SWT.SEPARATOR);
+//		fontsComboItem.setControl(fontCombo);
+//		fontCombo.pack();
+//		fontsComboItem.setWidth(fontCombo.getBounds().width);
 		
+		this.addControl(fontCombo);
+		
 		int currentFontIndex = 0;
 		for (int i = 0; i < fonts.length; i++) {
 			if (fonts[i].equals(currentFont.getName())) {
@@ -157,77 +162,110 @@
 		}
 		fontSizeCombo.setItems(fontSizes);
 		
-		ToolItem fontSizeComboItem = new ToolItem(this, SWT.SEPARATOR);
-		fontSizeComboItem.setControl(fontSizeCombo);
-		fontSizeCombo.pack();
-		fontSizeComboItem.setWidth(fontSizeCombo.getBounds().width);
+//		ToolItem fontSizeComboItem = new ToolItem(this, SWT.SEPARATOR);
+//		fontSizeComboItem.setControl(fontSizeCombo);
+//		fontSizeCombo.pack();
+//		fontSizeComboItem.setWidth(fontSizeCombo.getBounds().width);
 		
+		this.addControl(fontSizeCombo);
+		
 		fontSizeCombo.select(currentFontSizeIndex);
 		
-		// Font size
-//		fontStyleCombo = new Combo(this, SWT.READ_ONLY);
-//		String fontStyles[] = new String[] {"normal", "bold", "italic"};
-//		int currentFontStyleIndex = 0;
-//		fontStyleCombo.setItems(fontStyles);
+		
+		// Font style
+		fontStyleCombo = new Combo(this, SWT.READ_ONLY);
+
+		
+		//FIXME: SJ: the styles list should be builded from the available styles of the current selected font.
+		// Here are some tests to try to get the available styles
+		
+		// AWT
+//        for (Entry<TextAttribute, ?> mapElement : currentFont.getAttributes().entrySet()) {
+//            TextAttribute key = mapElement.getKey();
+//            System.out.println(key + " : " + mapElement.getValue());
+//        }
 //		
+//		for (Attribute a : currentFont.getAvailableAttributes()) {
+//			System.out.println("AdvancedChartEditorToolBar.AdvancedChartEditorToolBar()" + a);	
+//		}
+		// SWT/JFace
+//		FontData[] fontsData = this.getDisplay().getFontList(null, true);
+//		  for (int i = 0; i < fontsData.length; i++) {
+//		    System.out.println("AdvancedChartEditorToolBar.AdvancedChartEditorToolBar() - Fonts from SWT: " + fontsData[i].getName()
+//		    		+ " - " + fontsData[i].getLocale()
+//		    		+ " - " + fontsData[i].getHeight()
+//		    		+ " - " + fontsData[i].toString()
+//		    		);
+//		    System.out.println("AdvancedChartEditorToolBar.AdvancedChartEditorToolBar() " + StringConverter.asString(fontsData[i]));
+//		  }
+		
+		
+		String fontStyles[] = new String[] {"Regular", "Bold", "Italic", "Bold italic"};
+		int currentFontStyleIndex = currentFont.getStyle();
+		fontStyleCombo.setItems(fontStyles);
+		
 //		ToolItem fontStyleComboItem = new ToolItem(this, SWT.SEPARATOR);
 //		fontStyleComboItem.setControl(fontStyleCombo);
 //		fontStyleCombo.pack();
 //		fontStyleComboItem.setWidth(fontStyleCombo.getBounds().width);
-//		
-//		fontStyleCombo.select(currentFontStyleIndex);
 		
+		this.addControl(fontStyleCombo);
 		
+		fontStyleCombo.select(currentFontStyleIndex);
 		
+		
+		
 		// Chart types from installed chart creators in all installed charts engines
-		
+		chartTypeCombo = new Combo(this, SWT.READ_ONLY);
 		if (TBXPreferences.getInstance().getBoolean(TBXPreferences.EXPERT_USER)) {
 			
-			chartTypeCombo = new Combo(this, SWT.READ_ONLY);
-			
 			ArrayList<String> chartsEngineNames = new ArrayList<>();
 			ArrayList<ChartCreator> allChartCreators = new ArrayList<>();
 			
-			if (allChartCreators.size() > 1) {
-				for (ChartsEngine engine : ChartsEnginesManager.getChartsEngines()) {
-					for (ChartCreator creator : engine.getChartCreators(this.getEditorPart().getResult())) {
-						chartsEngineNames.add(engine.getName());
-						allChartCreators.add(creator);
-					}
+			for (ChartsEngine engine : ChartsEnginesManager.getChartsEngines()) {
+				for (ChartCreator creator : engine.getChartCreators(this.getEditorPart().getResult())) {
+					chartsEngineNames.add(engine.getName());
+					allChartCreators.add(creator);
 				}
+			}
+			
+
+			String chartTypes[] = new String[allChartCreators.size()];
+			int currentChartCreatorIndex = 0;
+			
+			for (int i = 0; i < allChartCreators.size(); i++) {
 				
+				chartTypes[i] = allChartCreators.get(i).getChartType();
+				if (chartTypes[i] == null) {
+					chartTypes[i] = ChartsEnginePreferences.DEFAULT_CHART_TYPE;
+				}
 				
-				String chartTypes[] = new String[allChartCreators.size()];
-				int currentChartCreatorIndex = 0;
-				
-				for (int i = 0; i < allChartCreators.size(); i++) {
-					
-					chartTypes[i] = allChartCreators.get(i).getChartType();
-					if (chartTypes[i] == null) {
-						chartTypes[i] = ChartsEnginePreferences.DEFAULT_CHART_TYPE;
-					}
-					
-					// preselected combo index
-					if (this.getEditorPart().getChartType() != null && this.getEditorPart().getChartType().equals(chartTypes[i])
-							&& this.getEditorPart().getResult().getChartsEngine().getName().equals(chartsEngineNames.get(i))) {
-						currentChartCreatorIndex = i;
-					}
-					
-					chartTypes[i] = chartsEngineNames.get(i) + " / " + chartTypes[i]; //$NON-NLS-1$
-					
+				// preselected combo index
+				if (this.getEditorPart().getChartType() != null && this.getEditorPart().getChartType().equals(chartTypes[i])
+						&& this.getEditorPart().getResult().getChartsEngine().getName().equals(chartsEngineNames.get(i))) {
+					currentChartCreatorIndex = i;
 				}
-				chartTypeCombo.setItems(chartTypes);
-				chartTypeCombo.select(currentChartCreatorIndex);
 				
-				ToolItem chartTypeComboItem = new ToolItem(this, SWT.SEPARATOR);
-				chartTypeComboItem.setControl(chartTypeCombo);
-				chartTypeCombo.pack();
-				chartTypeComboItem.setWidth(chartTypeCombo.getBounds().width);
+				chartTypes[i] = chartsEngineNames.get(i) + " / " + chartTypes[i]; //$NON-NLS-1$
 				
-				
-				
-				//chartTypeCombo.setVisible(false);
 			}
+			chartTypeCombo.setItems(chartTypes);
+			
+//			ToolItem chartTypeComboItem = new ToolItem(this, SWT.SEPARATOR);
+//			chartTypeComboItem.setControl(chartTypeCombo);
+//			chartTypeCombo.pack();
+//			chartTypeComboItem.setWidth(chartTypeCombo.getBounds().width);
+			
+
+			this.addControl(chartTypeCombo);
+			
+			
+			chartTypeCombo.select(currentChartCreatorIndex);
+			
+			
+			if (allChartCreators.size() < 2) {
+				chartTypeCombo.setVisible(false);
+			}
 		}
 		
 		
@@ -254,9 +292,9 @@
 				}
 				// end of FIXME
 				
-				// Font
-				else if (e.getSource() == fontCombo || e.getSource() == fontSizeCombo) { //  || e.getSource() == fontStyleCombo) {
-					getEditorPart().getResult().setFont("1|" + fontCombo.getItem(fontCombo.getSelectionIndex()) + "|" + fontSizeCombo.getItem(fontSizeCombo.getSelectionIndex()) + "|1"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ +fontStyleCombo.getSelectionIndex()
+				// Font 
+				else if (e.getSource() == fontCombo || e.getSource() == fontSizeCombo || e.getSource() == fontStyleCombo) {
+					getEditorPart().getResult().setFont("1|" + fontCombo.getItem(fontCombo.getSelectionIndex()) + "|" + fontSizeCombo.getItem(fontSizeCombo.getSelectionIndex()) + "|" + fontStyleCombo.getSelectionIndex()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 				}
 				// Chart type / chart creators
 				else if (e.getSource() == chartTypeCombo) {
@@ -300,7 +338,7 @@
 		if (renderingModeCombo != null) renderingModeCombo.addSelectionListener(listener);
 		if (fontCombo != null) fontCombo.addSelectionListener(listener);
 		if (fontSizeCombo != null) fontSizeCombo.addSelectionListener(listener);
-		//if (fontStyleCombo != null) fontStyleCombo.addSelectionListener(listener);
+		if (fontStyleCombo != null) fontStyleCombo.addSelectionListener(listener);
 		if (chartTypeCombo != null) chartTypeCombo.addSelectionListener(listener);
 	}
 	
Index: TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/swt/ChartEditorToolBar.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/swt/ChartEditorToolBar.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/swt/ChartEditorToolBar.java	(revision 3563)
@@ -14,7 +14,8 @@
  * @author sjacquot
  *
  */
-// FIXME: became useless? could now directly use TXMEditorToolBar
+// FIXME: SJ: became useless? could now directly use TXMEditorToolBar
+// If remove, check that the ID is not used and/or replace it in plugin.xml
 public class ChartEditorToolBar extends TXMEditorToolBar {
 	
 	
@@ -41,141 +42,6 @@
 	 */
 	public ChartEditorToolBar(ChartEditor<? extends ChartResult> chartEditor, Composite parent, GLComposite subWidgetsComposite, int style, String toolbarId) {
 		super(chartEditor, parent, subWidgetsComposite, style, toolbarId);
-		
-		
-		// FIXME: tests
-		// new ToolItem(this, SWT.SEPARATOR);
-		//
-		// final ToolItem showTitle = new ToolItem(this, SWT.CHECK);
-		// //showTitle.setText(SWTComponentsProviderMessages.showhideTitle);
-		// showTitle.setImage(IImageKeys.getImage(this, "icons/show_title.png"));
-		// showTitle.setDisabledImage(IImageKeys.getImage(this, "icons/show_title_disabled.png"));
-		// showTitle.setToolTipText(SWTComponentsProviderMessages.showhideTitle);
-		//
-		// if(!TXMPreferences.isEmpty(chartEditorPart.getPreferencesNodeQualifier(), ChartsEnginePreferences.SHOW_TITLE)) {
-		// showTitle.setSelection(TXMPreferences.getBoolean(chartEditorPart.getPreferencesNodeQualifier(), chartEditorPart.getResultData(), ChartsEnginePreferences.SHOW_TITLE));
-		// }
-		// // disable if not managed
-		// else {
-		// showTitle.setEnabled(false);
-		// }
-		//
-		//
-		// final ToolItem showLegend = new ToolItem(this, SWT.CHECK);
-		// //showLegend.setText(SWTComponentsProviderMessages.showhideLegend);
-		// showLegend.setImage(IImageKeys.getImage(this, "icons/show_legend.png"));
-		// showLegend.setDisabledImage(IImageKeys.getImage(this, "icons/show_legend_disabled.png"));
-		// showLegend.setToolTipText(SWTComponentsProviderMessages.showhideLegend);
-		//
-		// if(!TXMPreferences.isEmpty(chartEditorPart.getPreferencesNodeQualifier(), ChartsEnginePreferences.SHOW_LEGEND)) {
-		// showLegend.setSelection(TXMPreferences.getBoolean(chartEditorPart.getPreferencesNodeQualifier(), chartEditorPart.getResultData(), ChartsEnginePreferences.SHOW_LEGEND));
-		// }
-		// // disable if not managed
-		// else {
-		// showLegend.setEnabled(false);
-		// }
-		//
-		//
-		// final ToolItem showGrid = new ToolItem(this, SWT.CHECK);
-		// //showGrid.setText(SWTComponentsProviderMessages.showhideGrid);
-		// showGrid.setImage(IImageKeys.getImage(this, "icons/show_grid.png"));
-		// showGrid.setDisabledImage(IImageKeys.getImage(this, "icons/show_grid_disabled.png"));
-		// showGrid.setToolTipText(SWTComponentsProviderMessages.showhideGrid);
-		//
-		// if(!TXMPreferences.isEmpty(chartEditorPart.getPreferencesNodeQualifier(), ChartsEnginePreferences.SHOW_GRID)) {
-		// showGrid.setSelection(TXMPreferences.getBoolean(chartEditorPart.getPreferencesNodeQualifier(), chartEditorPart.getResultData(), ChartsEnginePreferences.SHOW_GRID));
-		// }
-		// // disable if not managed
-		// else {
-		// showGrid.setEnabled(false);
-		// }
-		//
-		//
-		//
-		// SelectionListener listener = new SelectionListener() {
-		//
-		// @Override
-		// public void widgetSelected(final SelectionEvent e) {
-		//
-		// // Accessing the source must be done outside the Job
-		// if(e.getSource() == showTitle) {
-		// TXMPreferences.putLocalBoolean(chartEditorPart.getResultData(), ChartsEnginePreferences.SHOW_TITLE,showTitle.getSelection());
-		// }
-		// if(e.getSource() == showLegend) {
-		// TXMPreferences.putLocalBoolean(chartEditorPart.getResultData(), ChartsEnginePreferences.SHOW_LEGEND, showLegend.getSelection());
-		// }
-		// if(e.getSource() == showGrid) {
-		// TXMPreferences.putLocalBoolean(chartEditorPart.getResultData(), ChartsEnginePreferences.SHOW_GRID, showGrid.getSelection());
-		// }
-		//
-		//
-		// // updates existing chart
-		// Job job = new Job("Update chart") {
-		//
-		// @Override
-		// protected IStatus run(final IProgressMonitor monitor) {
-		//
-		//
-		//
-		// // updating and reloading
-		// monitor.beginTask("Updating", IProgressMonitor.UNKNOWN);
-		// chartEditorPart.updateChart();
-		//
-		//
-		//
-		// // cancel
-		// if(monitor.isCanceled()) {
-		// return Status.CANCEL_STATUS;
-		// }
-		//
-		// // refreshes
-		// chartEditorPart.getSite().getShell().getDisplay().asyncExec(new Runnable() {
-		// @Override
-		// public void run() {
-		// CorporaView.refresh();
-		// }
-		// });
-		//
-		//
-		// // loading
-		// monitor.setTaskName("Loading");
-		// chartEditorPart.loadChart();
-		//
-		//
-		//
-		// // FIXME: persistence test, saving local preferences/parameters to file
-		// //TXMPreferences.flush(chartEditorPart.getResultData());
-		//
-		//
-		// // done
-		// monitor.done();
-		//
-		//
-		//// }
-		//// });
-		//
-		//
-		// return Status.OK_STATUS;
-		// }
-		//
-		// };
-		// //job.setUser(true); // show progress bar, without that the progress is located to bottom right
-		// job.schedule();
-		//
-		//
-		//
-		//
-		// }
-		//
-		// @Override
-		// public void widgetDefaultSelected(SelectionEvent e) {
-		// // TODO Auto-generated method stub
-		//
-		// }
-		// };
-		// showTitle.addSelectionListener(listener);
-		// showLegend.addSelectionListener(listener);
-		// showGrid.addSelectionListener(listener);
 	}
 	
 	
Index: TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/preferences/ChartsEnginePreferencePage.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/preferences/ChartsEnginePreferencePage.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.rcp/src/org/txm/chartsengine/rcp/preferences/ChartsEnginePreferencePage.java	(revision 3563)
@@ -111,7 +111,7 @@
 		
 		FontFieldEditor font = new FontFieldEditor(ChartsEnginePreferences.FONT, "Font", "Specificities / Spécificités / Специфичность", this.getFieldEditorParent()); //$NON-NLS-1$ //$NON-NLS-2$
 		this.addField(font);
-		// FIXME: preview area tests
+		// FIXME: SJ: preview area tests
 		// font.fillIntoGrid(this.getFieldEditorParent(), 4);
 		// ((Text)font.getPreviewControl()).setLayoutData(new GridData(GridData.FILL_BOTH));
 		// System.out.println("ChartsEnginePreferencePage.createFieldEditors() " + font.getPreviewControl());
Index: TXM/trunk/org.txm.chartsengine.r.core/src/org/txm/chartsengine/r/core/RChartsEngine.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.r.core/src/org/txm/chartsengine/r/core/RChartsEngine.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.r.core/src/org/txm/chartsengine/r/core/RChartsEngine.java	(revision 3563)
@@ -41,7 +41,7 @@
 	/**
 	 * Constants for extra output formats.
 	 */
-	// FIXME : for tests or further output formats implementations
+	// FIXME: SJ: for tests or further output formats implementations
 	// public final static String OUTPUT_FORMAT_RGRAPHICS = "rgraphics", OUTPUT_FORMAT_IPLOT = "iplots", OUTPUT_FORMAT_JAVAGD = "javagd"; //$NON-NLS-1$ //$NON-NLS-2$
 	
 	
@@ -215,17 +215,10 @@
 	 */
 	public String getTitlePlotCmd(String title) {
 		
-		// FIXME: Tests
-		// title(main = "Titre principal", sub = "Sous-titre",
-		// xlab = "Axe des x", ylab = "Axe des y",
-		// cex.main = 2, font.main= 4, col.main= "red",
-		// cex.sub = 0.75, font.sub = 3, col.sub = "green",
-		// col.lab ="darkblue"
-		// )
-		
+		// FIXME: SJ: old version without truncated title
 		// return String.format("title(main = \"%s\");\n", title); //$NON-NLS-1$
 		
-		// FIXME: tests for adaptive not truncated title
+		// FIXME: SJ: tests for adaptive not truncated title
 		return String.format("title(main = paste(strwrap(\"%s\", width = 50), collapse = \"\n\"));\n", title); //$NON-NLS-1$
 		
 		
@@ -238,7 +231,7 @@
 	 * @return
 	 */
 	public String getSubtitlePlotCmd(String subtitle) {
-		// NOTE: SJ: sub title always drawn the string at bottom of the plot
+		// FIXME: SJ: subtitle always drawn the string at bottom of the plot
 		// return String.format("title(sub = \"%s\");\n", subtitle); //$NON-NLS-1$
 		return String.format("title(main = \"\n\n\n%s\");\n", subtitle); //$NON-NLS-1$
 	}
@@ -284,7 +277,7 @@
 	public void setOutputFormat(String outputFormat) {
 		this.outputFormat = outputFormat;
 		
-		// FIXME : SJ: voir comment gérer cela autrement + supprimer certaines méthodes du RDevice devenues inutiles depuis qu'on stocke outputFormat ?
+		// FIXME: SJ: voir comment gérer cela autrement + supprimer certaines méthodes du RDevice devenues inutiles depuis qu'on stocke outputFormat ?
 		if (outputFormat.equals(ChartsEngine.OUTPUT_FORMAT_JPEG)) {
 			this.rDevice = RDevice.JPEG;
 		}
@@ -309,7 +302,7 @@
 	public ArrayList<String> getSupportedOutputDisplayFormats() {
 		ArrayList<String> formats = new ArrayList<>(1);
 		
-		// FIXME: UI display output format, only SVG
+		// FIXME: SJ: UI display output format, only SVG
 		// formats.add(outputFormatDefinitions.get(JFCChartsEngine.OUTPUT_FORMAT_SVG));
 		
 		return formats;
Index: TXM/trunk/org.txm.links.rcp/src/org/txm/links/rcp/handlers/SendSelectionToMatchable.java
===================================================================
--- TXM/trunk/org.txm.links.rcp/src/org/txm/links/rcp/handlers/SendSelectionToMatchable.java	(revision 3562)
+++ TXM/trunk/org.txm.links.rcp/src/org/txm/links/rcp/handlers/SendSelectionToMatchable.java	(revision 3563)
@@ -41,7 +41,7 @@
 import org.txm.links.rcp.messages.Messages;
 
 /**
- * Base command to send a selection to a command that needs a query to compute the new result.
+ * Base command to send a selection to a command that needs a result of query (List<Match>) to compute the new result.
  * 
  * @author mdecorde
  * @author sjacquot
@@ -77,8 +77,9 @@
 				Log.severe(Messages.bind(Messages.NoResultFondWithP0, event));
 				return null;
 			}
-			String resultParametersNodePath = result.getProject().getParametersNodeRootPath() + TXMResult.createUUID() + "_link"; // FIXME: we can't put the class name here since we does not know the //$NON-NLS-1$
-																																	 // target class
+			// FIXME: SJ: we can't put the class name here since we does not know the target class
+			String resultParametersNodePath = result.getProject().getParametersNodeRootPath() + TXMResult.createUUID() + "_link";  //$NON-NLS-1$
+
 			TXMPreferences.put(resultParametersNodePath, TXMPreferences.PARENT_PARAMETERS_NODE_PATH, result.getParametersNodePath());
 			TXMPreferences.put(resultParametersNodePath, TXMPreferences.MATCHES, matches.toString());
 			
Index: TXM/trunk/org.txm.links.rcp/src/org/txm/links/rcp/handlers/SendSelectionToQueryable.java
===================================================================
--- TXM/trunk/org.txm.links.rcp/src/org/txm/links/rcp/handlers/SendSelectionToQueryable.java	(revision 3562)
+++ TXM/trunk/org.txm.links.rcp/src/org/txm/links/rcp/handlers/SendSelectionToQueryable.java	(revision 3563)
@@ -92,8 +92,6 @@
 		
 		if (selection != null && !selection.isEmpty()) {
 			
-			
-			
 			String query = this.createQuery(event, selection);
 			String queries = this.createQueries(event, selection);
 			Integer index = this.getIndexResult(event, selection);
@@ -107,8 +105,9 @@
 			// create a local result node in the project node, store in some parameters and call the linked command
 			String id = event.getCommand().getId();
 			TXMResult result = this.getResultParent(event, id);
-			String resultParametersNodePath = result.getProject().getParametersNodeRootPath() + TXMResult.createUUID() + "_link"; // FIXME: we can't put the class name here since //$NON-NLS-1$
-																																	 // we does not know the target class
+			// FIXME: we can't put the class name here since we does not know the target class
+			String resultParametersNodePath = result.getProject().getParametersNodeRootPath() + TXMResult.createUUID() + "_link";  //$NON-NLS-1$
+
 			TXMPreferences.put(resultParametersNodePath, TXMPreferences.PARENT_PARAMETERS_NODE_PATH, result.getParametersNodePath());
 			TXMPreferences.put(resultParametersNodePath, TXMPreferences.QUERY, query);
 			TXMPreferences.put(resultParametersNodePath, TXMPreferences.QUERIES, queries);
Index: TXM/trunk/org.txm.statsengine.r.core/src/org/txm/statsengine/r/core/RResult.java
===================================================================
--- TXM/trunk/org.txm.statsengine.r.core/src/org/txm/statsengine/r/core/RResult.java	(revision 3562)
+++ TXM/trunk/org.txm.statsengine.r.core/src/org/txm/statsengine/r/core/RResult.java	(revision 3563)
@@ -1,5 +1,7 @@
 package org.txm.statsengine.r.core;
 
+//FIXME: SJ: find a better way to manage this, eg. define a getInternalId() method in TXMResult
+// Using this create a too strong link between result and engine
 public interface RResult {
 	/**
 	 * 
Index: TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/ChartsEngine.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/ChartsEngine.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/ChartsEngine.java	(revision 3563)
@@ -331,7 +331,7 @@
 	}
 	
 	/**
-	 * Creates a font from the specified encoded String in JFace format (e.g.: "1|Lucida Sans Unicode|12.0|0|WINDOWS|1|-16|0|0|0|400|0|0|0|0|3|2|1|34|Lucida Sans Unicode;")
+	 * Creates a AWT font from the specified encoded String (in JFace StringConverter format, e.g.: "1|Lucida Sans Unicode|12.0|0|WINDOWS|1|-16|0|0|0|400|0|0|0|0|3|2|1|34|Lucida Sans Unicode;").
 	 * 
 	 * @param encodedStr
 	 * @return the decoded font
@@ -339,13 +339,15 @@
 	public static Font createFont(String encodedStr) {
 		String[] data = encodedStr.split("\\|");
 		Font font = new Font(data[1], // font name
-					Integer.valueOf(data[3]), // font style
+				//3, // font style
+				Integer.valueOf(data[3]), // font style
+					
 					Integer.parseInt(data[2].split("\\.")[0])); // font size
 		return font;
 	}
 	
 	/**
-	 * Creates a font from the current global charts engine font preference.
+	 * Creates a AWT font from the current global charts engine font preference encoded String (in JFace StringConverter format, e.g.: "1|Lucida Sans Unicode|12.0|0|WINDOWS|1|-16|0|0|0|400|0|0|0|0|3|2|1|34|Lucida Sans Unicode;").
 	 * 
 	 * @return
 	 */
Index: TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/preferences/ChartsEnginePreferences.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/preferences/ChartsEnginePreferences.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/preferences/ChartsEnginePreferences.java	(revision 3563)
@@ -16,6 +16,7 @@
 public class ChartsEnginePreferences extends TXMPreferences {
 	
 	
+	// Engine preferences
 	/**
 	 * The name of the current charts engine.
 	 */
@@ -35,6 +36,7 @@
 	
 	
 	
+	// Result preferences
 	/**
 	 * Constant for showing title or not in the charts.
 	 */
@@ -74,8 +76,6 @@
 	 */
 	public static final String MULTIPLE_LINE_STROKES = "multiple_line_strokes"; //$NON-NLS-1$
 	
-	
-	// local result preferences
 	/**
 	 * Chart type.
 	 */
@@ -87,6 +87,7 @@
 	public final static String DEFAULT_CHART_TYPE = "[Default]"; //$NON-NLS-1$
 	
 	
+	
 	/**
 	 * Gets the instance.
 	 * 
@@ -125,13 +126,13 @@
 		preferences.put(MONOCHROME_COLOR, "0,220,20"); //$NON-NLS-1$
 		preferences.putBoolean(MULTIPLE_LINE_STROKES, false);
 		
-		// Check the target OS and set the default font from the JVM embedded font
+		// Check the target OS and set the default font using encoded String in JFace StringConverter format (?|Font name|size|style|?|?|...)
 		String defaultFont;
 		if (OSDetector.isFamilyUnix()) {
-			defaultFont = "1|Lucida Sans|11.0|0|GTK|1|"; //$NON-NLS-1$ // other version if needed later: "1|Lucida Sans|11|0"
+			defaultFont = "1|Lucida Sans|11.0|1|GTK|1|"; //$NON-NLS-1$
 		}
 		else {
-			defaultFont = "1|Lucida Sans Unicode|11.0|0|WINDOWS|1|-16|0|0|0|400|0|0|0|0|3|2|1|34|Lucida Sans Unicode;"; //$NON-NLS-1$
+			defaultFont = "1|Lucida Sans Unicode|11.0|1|WINDOWS|1|-16|0|0|0|400|0|0|0|0|3|2|1|34|Lucida Sans Unicode;"; //$NON-NLS-1$
 		}
 		
 		preferences.put(FONT, defaultFont);
@@ -144,9 +145,10 @@
 	 * @param enginesOrder
 	 * @return
 	 */
+	//FIXME: SJ: not fully tested and unfinished feature
 	public static String[] getEnginesOrder(String enginesOrder) {
 		
-		String[] orderedEnginesNames = enginesOrder.split("\\|");
+		String[] orderedEnginesNames = enginesOrder.split("\\|"); //$NON-NLS-1$
 		
 		if (orderedEnginesNames.length == 1 && orderedEnginesNames[0].isEmpty()) {
 			return null;
@@ -163,16 +165,17 @@
 	 * @param enginesNames
 	 * @return
 	 */
+	//FIXME: SJ: not fully tested and unfinished feature
 	public static String createEnginesOrder(String[] enginesNames) {
 		StringBuilder sb = new StringBuilder();
 		for (int i = 0; i < enginesNames.length; i++) {
 			if (i > 0) {
-				sb.append("|");
+				sb.append("|"); //$NON-NLS-1$
 			}
 			sb.append(enginesNames[i]);
 		}
 		
-		Log.finest("ChartsEnginePreferences.createChartsEnginesOrder():" + sb);
+		Log.finest("ChartsEnginePreferences.createChartsEnginesOrder():" + sb); //$NON-NLS-1$
 		
 		return sb.toString();
 	}
@@ -183,6 +186,7 @@
 	 * @param enginesOrder
 	 * @return
 	 */
+	//FIXME: SJ: not fully tested and unfinished feature
 	public static String getFirstEngineName() {
 		return getEnginesOrder(getInstance().getString(CHARTS_ENGINES_ORDER))[0];
 	}
@@ -193,6 +197,7 @@
 	 * 
 	 * @return
 	 */
+	//FIXME: SJ: not fully tested and unfinished feature
 	public String[] getEnginesOrder() {
 		return getEnginesOrder(this.getString(ChartsEnginePreferences.CHARTS_ENGINES_ORDER));
 	}
Index: TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/results/ChartResult.java
===================================================================
--- TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/results/ChartResult.java	(revision 3562)
+++ TXM/trunk/org.txm.chartsengine.core/src/org/txm/chartsengine/core/results/ChartResult.java	(revision 3563)
@@ -676,7 +676,7 @@
 	
 	
 	/**
-	 * Sets the font.
+	 * Sets the font using encoded String in JFace StringConverter format (e.g.: "1|Lucida Sans Unicode|12.0|0|WINDOWS|1|-16|0|0|0|400|0|0|0|0|3|2|1|34|Lucida Sans Unicode;").
 	 * 
 	 * @param font the font to set
 	 */
Index: TXM/trunk/org.txm.searchengine.cqp.core/src/org/txm/searchengine/cqp/CQPPreferences.java
===================================================================
--- TXM/trunk/org.txm.searchengine.cqp.core/src/org/txm/searchengine/cqp/CQPPreferences.java	(revision 3562)
+++ TXM/trunk/org.txm.searchengine.cqp.core/src/org/txm/searchengine/cqp/CQPPreferences.java	(revision 3563)
@@ -1,6 +1,5 @@
 package org.txm.searchengine.cqp;
 
-import org.osgi.service.prefs.Preferences;
 import org.txm.core.preferences.TXMPreferences;
 
 /**
@@ -14,7 +13,7 @@
 	
 
 	/**
-	 * List of part names
+	 * List of part names.
 	 */
 	public static final String PART_NAMES = "part_names"; //$NON-NLS-1$
 	
@@ -34,6 +33,5 @@
 	@Override
 	public void initializeDefaultPreferences() {
 		super.initializeDefaultPreferences();
-		Preferences preferences = this.getDefaultPreferencesNode();
 	}
 }

Index: TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditorToolBar.java
===================================================================
--- TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditorToolBar.java	(revision 3562)
+++ TXM/trunk/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditorToolBar.java	(revision 3563)
@@ -11,6 +11,7 @@
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.RowLayout;
+import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Event;
@@ -70,7 +71,8 @@
 	public TXMEditorToolBar(TXMEditor<? extends TXMResult> editor, Composite parent, GLComposite subWidgetComposite, int style, String toolbarId) {
 		super(parent, style);
 		
-		this.setLayout(new FillLayout());
+		FillLayout layout = new FillLayout();
+		this.setLayout(layout);
 		
 		this.editorPart = editor;
 		this.subWidgetComposite = subWidgetComposite;
@@ -147,25 +149,28 @@
 	
 	
 	/**
 	 * Adds the specified control to this toolbar.
 	 * Convenience method to add non-ToolItem controls to the toolbar using the SWT.SEPARATOR trick, plus packing and setting the right width.
 	 * 
-	 * Warning: the item size is not synchronized with the control size
-	 * 
-	 * @param control
+	 * @param combo
 	 */
-	public void addControl(final Control control) {
+	public void addControl(final Combo combo) {
 		final ToolItem itemSeparator = new ToolItem(this, SWT.SEPARATOR);
-		control.pack();
-		itemSeparator.setWidth(control.getBounds().width);
-		itemSeparator.setControl(control);
-		control.addListener(SWT.RESIZE, new Listener() {
+		combo.pack();
+		itemSeparator.setWidth(combo.getBounds().width);
+		itemSeparator.setControl(combo);
+		Listener listener = new Listener() {
 			
 			@Override
 			public void handleEvent(Event event) {
-				itemSeparator.setWidth(control.getBounds().width);
+				combo.pack();
+				itemSeparator.setWidth(combo.getBounds().width);
 			}
-		});
+		};
+
+		
+		combo.addListener(SWT.RESIZE, listener);
+		combo.addListener(SWT.Modify, listener);
 	}
 	
 	/**
@@ -270,7 +275,10 @@
 		layout.wrap = true;
 		layout.center = true;
 		layout.spacing = 8;
-		layout.marginWidth = layout.marginBottom = layout.marginHeight = layout.marginTop = 0;
+		layout.marginWidth = 0;
+		layout.marginBottom = 0;
+		layout.marginHeight = 0;
+		layout.marginTop = 0;
 		
 		group.setLayout(layout);
 		
@@ -147,25 +149,28 @@
 	
 	/**
-	 * Adds the specified control to this toolbar.
-	 * Convenience method to add non-ToolItem controls to the toolbar using the SWT.SEPARATOR trick, plus packing and setting the right width.
+	 * Adds the specified Combo to this tool bar.
+	 * Convenience method to add non-ToolItem Combo to the tool bar using the SWT.SEPARATOR trick, plus to pack and to set the right width.
 	 * 
Index: TXM/trunk/org.txm.core/src/java/org/txm/core/results/TXMResult.java
===================================================================
--- TXM/trunk/org.txm.core/src/java/org/txm/core/results/TXMResult.java	(revision 3562)
+++ TXM/trunk/org.txm.core/src/java/org/txm/core/results/TXMResult.java	(revision 3563)
@@ -8,6 +8,7 @@
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.HashMap;
@@ -67,8 +68,8 @@
  * </pre>
  * 
  * @author mdecorde
- * 
  * @author sjacquot
+ * 
  */
 public abstract class TXMResult implements Cloneable, Comparable<TXMResult> {
 	
@@ -106,7 +107,7 @@
 	private boolean dirty = true;
 	
 	/**
-	 * if a method changed the internal data without **recomputing** the result, the result must be marked "altered"
+	 * If a method changed the internal data without **recomputing** the result, the result must be marked "altered"
 	 */
 	private boolean altered = false;
 	
@@ -124,7 +125,6 @@
 	 * Command preferences node path.
 	 */
 	protected String commandPreferencesNodePath;
-	// protected IEclipsePreferences preferencesNode; // TODO: directly use a preferences node rather than a node path?
 	
 	/**
 	 * Parameters node path. Concatenation of the Project scope path + the result uuid
@@ -139,6 +139,7 @@
 	/**
 	 * To manage the computing cancel with TreadDeath.
 	 */
+	// FIXME: SJ: became useless? 
 	private Semaphore progressSemaphore = new Semaphore(1);
 	
 	/**
@@ -194,7 +195,6 @@
 	/**
 	 * Current computing state.
 	 * True if the result is in the process of computing (is in compute(,) method)
-	 * 
 	 */
 	private boolean computing = false;
 	
@@ -216,7 +216,7 @@
 	
 	/**
 	 * Creates a new TXMResult with no parent.
-	 * If a local node exist with the parent_uuid, the parent will be retrieved and this result will be added to it.
+	 * If a local preference node exists with parent_parameters_node_path value, the parent will be retrieved and this result will be added to it.
 	 * 
 	 * @param parametersNodePath
 	 */
@@ -250,7 +250,7 @@
 			
 			this.parametersNodePath = parametersNodePath + createUUID() + "_" + this.getClass().getSimpleName(); //$NON-NLS-1$ ;
 		}
-		// lazy or linked result
+		// lazy result (persistence / import) or linked result ("send to" commands)
 		else {
 			this.parametersNodePath = parametersNodePath;
 		}
@@ -273,26 +273,27 @@
 			this.saveParameter(TXMPreferences.PERSITABLE, true);
 		}
 		
-		// retrieving parent from UUID
+		// retrieving parent from UUID/node path
 		String parentNodePath = this.getStringParameterValue(TXMPreferences.PARENT_PARAMETERS_NODE_PATH);
 		
 		// System.out.println("TXMResult.TXMResult(): parent UUID = " + parentUUID);
 		
-		if (!("ROOT".equals(this.parametersNodePath)) && // search for parent only if UUID != "ROOT"
+		 // search for parent only if UUID != "ROOT"
+		if (!("ROOT".equals(this.parametersNodePath)) && //$NON-NLS-1$
 				parent == null &&
 				this.parametersNodePath != null &&
 				!parentNodePath.isEmpty()) {
 			
-			Log.finest("Searching parent with UUID " + parentNodePath + "..."); //$NON-NLS-1$ //$NON-NLS-2$
+			Log.finest("Searching parent with UUID/node path " + parentNodePath + "..."); //$NON-NLS-1$ //$NON-NLS-2$
 			
 			// FIXME: MD: this is quite CPU expensive because 'retrievedParent' researches in all projects
 			TXMResult retrievedParent = TXMResult.getResult(parentNodePath);
 			if (retrievedParent != null) {
-				Log.finest("Parent retrieved from UUID: " + retrievedParent + "."); //$NON-NLS-1$ //$NON-NLS-2$
+				Log.finest("Parent retrieved from UUID/node path: " + retrievedParent + "."); //$NON-NLS-1$ //$NON-NLS-2$
 				retrievedParent.addChild(this);
 			}
 			else {
-				Log.severe("Warning: no parent was found in project for path=" + parametersNodePath + " and puuid=" + parentNodePath + " preferences=" + this.dumpParameters()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+				Log.severe("Warning: no parent was found in project for result parameters UUID/node path=" + parametersNodePath + " and parent UUID/node path=" + parentNodePath + " - current parameters=" + this.dumpParameters()); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 				try {
 					TBXPreferences.delete(this);
 				}
@@ -309,9 +310,9 @@
 			this.loadParameters(); // subclasses manual settings
 			
 			try {
-				if (creationDate == null) {
-					creationDate = Calendar.getInstance().getTime();
-					this.saveParameter(TBXPreferences.CREATION_DATE, ID_TIME_FORMAT.format(creationDate));
+				if (this.creationDate == null) {
+					this.creationDate = Calendar.getInstance().getTime();
+					this.saveParameter(TBXPreferences.CREATION_DATE, ID_TIME_FORMAT.format(this.creationDate));
 				}
 			}
 			catch (Exception e) {
@@ -326,21 +327,21 @@
 		
 		// Log
 		if (this.parent == null) {
-			Log.finest("Warning: the TXMResult of " + this.getClass() + " is attached to no parent. (uuid = " + this.parametersNodePath + ")"); //$NON-NLS-1$ //$NON-NLS-2$
+			Log.finest("Warning: the TXMResult of " + this.getClass() + " is attached to no parent. (uuid = " + this.parametersNodePath + ")"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-1$
 		}
 	}
 	
 	/**
 	 * Sets the user name.
 	 * 
-	 * @param name
+	 * @param name a string dedicated to be defined by the user 
 	 */
 	public void setUserName(String name) {
 		this.userName = name;
 	}
 	
 	/**
-	 * @return true is the internal data has been modified
+	 * @return true if the internal data has been modified
 	 */
 	public boolean isAltered() {
 		return altered;
@@ -391,13 +392,11 @@
 	}
 	
 	/**
-	 * Creates an UUID dedicated to persistence of this result.
+	 * Creates an UUID dedicated to preferences/parameters storing and to persistence of a result.
 	 * 
 	 * @return
 	 */
 	public static String createUUID() {
-		// FIXME: SJ: see if it's useful to put the class name or not, should be better to save it in the .prefs
-		// this.uniqueID = this.getClass().getName() + '@' + ID_TIME_FORMAT.format(new Date(System.currentTimeMillis())) + "_" + UUID.randomUUID();
 		return UUID_PREFIX + ID_TIME_FORMAT.format(new Date(System.currentTimeMillis())) + "_" + nextInt();
 	}
 	
@@ -410,7 +409,7 @@
 	}
 	
 	/**
-	 * Checks if the result at least one child.
+	 * Checks if the result has at least one child.
 	 * 
 	 * @return
 	 */
@@ -420,7 +419,7 @@
 	
 	
 	/**
-	 * Gets the preferences node path of the result command.
+	 * Gets the preferences node path of the result linked command.
 	 * 
 	 * @return
 	 */
@@ -474,7 +473,7 @@
 	}
 	
 	/**
-	 * Stores the parameters of the specified types used for last computing in the specified HashMap.
+	 * Stores the parameters of the specified types used during last computing in the specified HashMap.
 	 * 
 	 * @param parameterTypes
 	 * @param appendToLastParameters
@@ -518,7 +517,7 @@
 	}
 	
 	/**
-	 * Stores the last parameters of the specified types used for computing.
+	 * Stores the last parameters of the specified types used during last computing.
 	 * 
 	 * @param parametersTypes
 	 * @throws Exception
@@ -528,7 +527,7 @@
 	}
 	
 	/**
-	 * Stores the last parameters used for computing.
+	 * Stores the last parameters used during last computing.
 	 * 
 	 * @throws Exception
 	 */
@@ -683,7 +682,7 @@
 	
 	
 	/**
 	 * Dumps the command and default preferences of the result preferences node qualifier.
 	 * 
 	 * @return
 	 */
@@ -726,7 +725,7 @@
 		
 		StringBuilder str = new StringBuilder();
 		
-		str.append("Parameters (type = " + parametersType + " / " + Parameter.types[parametersType] + ")\n"); //$NON-NLS-1$
+		str.append("Parameters (type = " + parametersType + " / " + Parameter.types[parametersType] + ")\n"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 		
 		List<Field> fields = BeanParameters.getAllFields(this);
 		
@@ -2239,9 +2238,7 @@
 	public abstract boolean canCompute() throws Exception;
 	
 	
-	/**
-	 * 
-	 */
+	// FIXME: SJ: became useless 
 	public void acquireSemaphore() {
 		try {
 			this.progressSemaphore.acquire();
@@ -2305,7 +2302,7 @@
 		
 		// FIXME: SJ: Debug tests
 		boolean debugSlowingProcess = false;
-		int sleepDuration = 5000;
+		int sleepDuration = 15000;
 		
 		// skip the process if the result is already in computing stage
 		if (this.computing) {
@@ -2598,17 +2595,12 @@
 	
 	
 	
-	/**
-	 * 
-	 * @return
-	 */
+	// FIXME: SJ: became useless?
 	public boolean tryAcquireSemaphore() {
 		return this.progressSemaphore.tryAcquire();
 	}
 	
-	/**
-	 * 
-	 */
+	// FIXME: SJ: became useless?
 	public void releaseSemaphore() {
 		this.progressSemaphore.release();
 	}
@@ -683,7 +682,7 @@
 	
 	/**
-	 * Dumps the command and default preferences of the result preferences node qualifier.
+	 * Dumps the result current parameters, the command user preferences and the command default preferences linked to the result.
 	 * 
 	 * @return